@@ -12,7 +12,6 @@ from typing import Optional, ClassVar, Type
 
 from jaraco.collections import FoldedCaseKeyedDict
 
-import six
 from lxml.etree import Element, fromstring, tostring
 from lxml.builder import ElementMaker as _ElementMaker
 
@@ -25,7 +24,7 @@ log = logging.getLogger(__name__)
 ElementClass = Element('__').__class__
 
 ooxml_namespaces = dict(
-    cp='http://schemas.openxmlformats.org/package/2006/metadata/' 'core-properties',
+    cp='http://schemas.openxmlformats.org/package/2006/metadata/core-properties',
     dc='http://purl.org/dc/elements/1.1/',
     dcterms='http://purl.org/dc/terms/',
     dcmitype='http://purl.org/dc/dcmitype/',
@@ -33,7 +32,7 @@ ooxml_namespaces = dict(
 )
 
 
-class Relational(object):
+class Relational:
     "A mixin class for packages and parts; both support relationships."
 
     def relate(self, part, id=None):
@@ -190,7 +189,7 @@ class Package(collections.abc.MutableMapping, Relational):
         return next(self.get_parts_by_class(CoreProperties))
 
 
-class DefaultNamed(object):
+class DefaultNamed:
     """
     Mix-in for Parts that have a default name. Subclasses should include
     a 'default_name' attribute, which will be used during construction
@@ -229,8 +228,7 @@ class RelationshipTypeHandler(type):
         return cls
 
 
-@six.add_metaclass(RelationshipTypeHandler)
-class Part(Relational):
+class Part(Relational, metaclass=RelationshipTypeHandler):
     """
     Parts are the building blocks of OOXML files.
 
@@ -284,7 +282,7 @@ class Part(Relational):
         data = self.data
         if isinstance(data, ElementClass):
             data = tostring(data, encoding='utf-8', pretty_print=True)
-        if isinstance(data, six.text_type):
+        if isinstance(data, str):
             return data.encode('utf-8')
         return data
 
@@ -292,7 +290,7 @@ class Part(Relational):
         self.data = data
 
 
-class Relationship(object):
+class Relationship:
     """Represents an OPC relationship between a Package/Part and another Part.
 
     source : a Package or Part instance
@@ -320,7 +318,7 @@ class Relationship(object):
 
     @validator
     def _validate_target(self, target):
-        assert isinstance(target, six.string_types), "target must be a part name"
+        assert isinstance(target, str), "target must be a part name"
         return target
 
     @validator
@@ -492,7 +490,7 @@ class ContentTypes(set):
         return self._item_map(ContentType.Override)
 
 
-class ContentType(object):
+class ContentType:
     """
     An abstract content type.
     Each content type has a name, which is a mime-type like
@@ -579,12 +577,28 @@ E = type(
 )
 
 
+def DC(tag):
+    return '{%(dc)s}' % ooxml_namespaces + tag
+
+
+def CP(tag):
+    return '{%(cp)s}' % ooxml_namespaces + tag
+
+
+def DCTERMS(tag):
+    return '{%(dcterms)s}' % ooxml_namespaces + tag
+
+
+def identity(x):
+    return x
+
+
 class CoreProperties(Part):
     """
     Core properties on a package, has attributes like 'title', and 'subject'
     """
 
-    content_type = "application/" "vnd.openxmlformats-package.core-properties+xml"
+    content_type = "application/vnd.openxmlformats-package.core-properties+xml"
     rel_type = (
         "http://schemas.openxmlformats.org/package/2006/"
         "relationships/metadata/core-properties"
@@ -606,18 +620,6 @@ class CoreProperties(Part):
     def load(self, data):
         xml = fromstring(data)
 
-        def DC(tag):
-            return '{%(dc)s}' % ooxml_namespaces + tag
-
-        def CP(tag):
-            return '{%(cp)s}' % ooxml_namespaces + tag
-
-        def DCTERMS(tag):
-            return '{%(dcterms)s}' % ooxml_namespaces + tag
-
-        def identity(x):
-            return x
-
         def set_attr_if_tag(tag, attr=None, transform=identity):
             if attr is None:
                 ns, attr = parse_tag(tag)
